@@ -401,13 +401,15 @@ get_one_xattr (const char *path,
   char value[64];
   char *value_p;
   ssize_t len;
+  int errsv;
 
   len = g_getxattr (path, xattr, value, sizeof (value)-1, follow_symlinks);
+  errsv = errno;
 
   value_p = NULL;
   if (len >= 0)
     value_p = value;
-  else if (len == -1 && errno == ERANGE)
+  else if (len == -1 && errsv == ERANGE)
     {
       len = g_getxattr (path, xattr, NULL, 0, follow_symlinks);
 
@@ -460,6 +462,8 @@ get_xattrs (const char            *path,
 
   if (all)
     {
+      int errsv;
+
       list_res_size = g_listxattr (path, NULL, 0, follow_symlinks);
 
       if (list_res_size == -1 ||
@@ -472,8 +476,9 @@ get_xattrs (const char            *path,
     retry:
       
       list_res_size = g_listxattr (path, list, list_size, follow_symlinks);
+      errsv = errno;
       
-      if (list_res_size == -1 && errno == ERANGE)
+      if (list_res_size == -1 && errsv == ERANGE)
 	{
 	  list_size = list_size * 2;
 	  list = g_realloc (list, list_size);
@@ -558,13 +563,15 @@ get_one_xattr_from_fd (int         fd,
   char value[64];
   char *value_p;
   ssize_t len;
+  int errsv;
 
   len = g_fgetxattr (fd, xattr, value, sizeof (value) - 1);
+  errsv = errno;
 
   value_p = NULL;
   if (len >= 0)
     value_p = value;
-  else if (len == -1 && errno == ERANGE)
+  else if (len == -1 && errsv == ERANGE)
     {
       len = g_fgetxattr (fd, xattr, NULL, 0);
 
@@ -615,6 +622,8 @@ get_xattrs_from_fd (int                    fd,
 
   if (all)
     {
+      int errsv;
+
       list_res_size = g_flistxattr (fd, NULL, 0);
 
       if (list_res_size == -1 ||
@@ -627,8 +636,9 @@ get_xattrs_from_fd (int                    fd,
     retry:
       
       list_res_size = g_flistxattr (fd, list, list_size);
+      errsv = errno;
       
-      if (list_res_size == -1 && errno == ERANGE)
+      if (list_res_size == -1 && errsv == ERANGE)
 	{
 	  list_size = list_size * 2;
 	  list = g_realloc (list, list_size);
@@ -1264,7 +1274,7 @@ get_content_type (const char          *basename,
 	{
 	  guchar sniff_buffer[4096];
 	  gsize sniff_length;
-	  int fd;
+	  int fd, errsv;
 
 	  sniff_length = _g_unix_content_type_get_sniff_len ();
 	  if (sniff_length > 4096)
@@ -1272,7 +1282,8 @@ get_content_type (const char          *basename,
 
 #ifdef O_NOATIME	  
           fd = g_open (path, O_RDONLY | O_NOATIME, 0);
-          if (fd < 0 && errno == EPERM)
+          errsv = errno;
+          if (fd < 0 && errsv == EPERM)
 #endif
 	    fd = g_open (path, O_RDONLY, 0);
 
