@@ -33,7 +33,7 @@ test_unichar_validate (void)
   g_assert (g_unichar_validate ('j'));
   g_assert (g_unichar_validate (8356));
   g_assert (g_unichar_validate (8356));
-  g_assert (!g_unichar_validate (0xfdd1));
+  g_assert (g_unichar_validate (0xfdd1));
   g_assert (g_unichar_validate (917760));
   g_assert (!g_unichar_validate (0x110000));
 }
@@ -131,7 +131,10 @@ test_unichar_break_type (void)
     { G_UNICODE_BREAK_HANGUL_LVT_SYLLABLE, 0xAC01 },
     { G_UNICODE_BREAK_CONDITIONAL_JAPANESE_STARTER, 0x3041 },
     { G_UNICODE_BREAK_HEBREW_LETTER,                0x05D0 },
-    { G_UNICODE_BREAK_REGIONAL_INDICATOR,           0x1F1F6 }
+    { G_UNICODE_BREAK_REGIONAL_INDICATOR,           0x1F1F6 },
+    { G_UNICODE_BREAK_EMOJI_BASE,          0x1F466 },
+    { G_UNICODE_BREAK_EMOJI_MODIFIER,      0x1F3FB },
+    { G_UNICODE_BREAK_ZERO_WIDTH_JOINER,   0x200D },
   };
 
   for (i = 0; i < G_N_ELEMENTS (examples); i++)
@@ -252,12 +255,51 @@ test_unichar_script (void)
     { G_UNICODE_SCRIPT_MIAO,                   0x16F00 },
     { G_UNICODE_SCRIPT_SHARADA,                0x11180 },
     { G_UNICODE_SCRIPT_SORA_SOMPENG,           0x110D0 },
-    { G_UNICODE_SCRIPT_TAKRI,                  0x11680 }
+    { G_UNICODE_SCRIPT_TAKRI,                  0x11680 },
+    { G_UNICODE_SCRIPT_BASSA_VAH,              0x16AD0 },
+    { G_UNICODE_SCRIPT_CAUCASIAN_ALBANIAN,     0x10530 },
+    { G_UNICODE_SCRIPT_DUPLOYAN,               0x1BC00 },
+    { G_UNICODE_SCRIPT_ELBASAN,                0x10500 },
+    { G_UNICODE_SCRIPT_GRANTHA,                0x11301 },
+    { G_UNICODE_SCRIPT_KHOJKI,                 0x11200 },
+    { G_UNICODE_SCRIPT_KHUDAWADI,              0x112B0 },
+    { G_UNICODE_SCRIPT_LINEAR_A,               0x10600 },
+    { G_UNICODE_SCRIPT_MAHAJANI,               0x11150 },
+    { G_UNICODE_SCRIPT_MANICHAEAN,             0x10AC0 },
+    { G_UNICODE_SCRIPT_MENDE_KIKAKUI,          0x1E800 },
+    { G_UNICODE_SCRIPT_MODI,                   0x11600 },
+    { G_UNICODE_SCRIPT_MRO,                    0x16A40 },
+    { G_UNICODE_SCRIPT_NABATAEAN,              0x10880 },
+    { G_UNICODE_SCRIPT_OLD_NORTH_ARABIAN,      0x10A80 },
+    { G_UNICODE_SCRIPT_OLD_PERMIC,             0x10350 },
+    { G_UNICODE_SCRIPT_PAHAWH_HMONG,           0x16B00 },
+    { G_UNICODE_SCRIPT_PALMYRENE,              0x10860 },
+    { G_UNICODE_SCRIPT_PAU_CIN_HAU,            0x11AC0 },
+    { G_UNICODE_SCRIPT_PSALTER_PAHLAVI,        0x10B80 },
+    { G_UNICODE_SCRIPT_SIDDHAM,                0x11580 },
+    { G_UNICODE_SCRIPT_TIRHUTA,                0x11480 },
+    { G_UNICODE_SCRIPT_WARANG_CITI,            0x118A0 },
+    { G_UNICODE_SCRIPT_CHEROKEE,               0x0AB71 },
+    { G_UNICODE_SCRIPT_HATRAN,                 0x108E0 },
+    { G_UNICODE_SCRIPT_OLD_HUNGARIAN,          0x10C80 },
+    { G_UNICODE_SCRIPT_MULTANI,                0x11280 },
+    { G_UNICODE_SCRIPT_AHOM,                   0x11700 },
+    { G_UNICODE_SCRIPT_CUNEIFORM,              0x12480 },
+    { G_UNICODE_SCRIPT_ANATOLIAN_HIEROGLYPHS,  0x14400 },
+    { G_UNICODE_SCRIPT_SIGNWRITING,            0x1D800 },
+    { G_UNICODE_SCRIPT_ADLAM,                  0x1E900 },
+    { G_UNICODE_SCRIPT_BHAIKSUKI,              0x11C00 },
+    { G_UNICODE_SCRIPT_MARCHEN,                0x11C70 },
+    { G_UNICODE_SCRIPT_NEWA,                   0x11400 },
+    { G_UNICODE_SCRIPT_OSAGE,                  0x104B0 },
+    { G_UNICODE_SCRIPT_TANGUT,                 0x16FE0 },
+    { G_UNICODE_SCRIPT_MASARAM_GONDI,          0x11D00 },
+    { G_UNICODE_SCRIPT_NUSHU,                  0x1B170 },
+    { G_UNICODE_SCRIPT_SOYOMBO,                0x11A50 },
+    { G_UNICODE_SCRIPT_ZANABAZAR_SQUARE,       0x11A00 },
   };
   for (i = 0; i < G_N_ELEMENTS (examples); i++)
-    {
-      g_assert_cmpint (g_unichar_get_script (examples[i].c), ==, examples[i].script);
-    }
+    g_assert_cmpint (g_unichar_get_script (examples[i].c), ==, examples[i].script);
 }
 
 static void
@@ -418,6 +460,8 @@ test_wide (void)
     {   0xFFFC, NOT_WIDE },
     {  0x10000, NOT_WIDE },
     {  0xE0001, NOT_WIDE },
+    {  0x2FFFE, NOT_WIDE },
+    {  0x3FFFE, NOT_WIDE },
 
     /* Narrow */
     {   0x0020, NOT_WIDE },
@@ -804,6 +848,53 @@ test_iso15924 (void)
     { G_UNICODE_SCRIPT_SHARADA,                "Shrd" },
     { G_UNICODE_SCRIPT_SORA_SOMPENG,           "Sora" },
     { G_UNICODE_SCRIPT_TAKRI,                  "Takr" },
+
+    /* Unicode 7.0 additions */
+    { G_UNICODE_SCRIPT_BASSA_VAH,              "Bass" },
+    { G_UNICODE_SCRIPT_CAUCASIAN_ALBANIAN,     "Aghb" },
+    { G_UNICODE_SCRIPT_DUPLOYAN,               "Dupl" },
+    { G_UNICODE_SCRIPT_ELBASAN,                "Elba" },
+    { G_UNICODE_SCRIPT_GRANTHA,                "Gran" },
+    { G_UNICODE_SCRIPT_KHOJKI,                 "Khoj" },
+    { G_UNICODE_SCRIPT_KHUDAWADI,              "Sind" },
+    { G_UNICODE_SCRIPT_LINEAR_A,               "Lina" },
+    { G_UNICODE_SCRIPT_MAHAJANI,               "Mahj" },
+    { G_UNICODE_SCRIPT_MANICHAEAN,             "Manu" },
+    { G_UNICODE_SCRIPT_MENDE_KIKAKUI,          "Mend" },
+    { G_UNICODE_SCRIPT_MODI,                   "Modi" },
+    { G_UNICODE_SCRIPT_MRO,                    "Mroo" },
+    { G_UNICODE_SCRIPT_NABATAEAN,              "Nbat" },
+    { G_UNICODE_SCRIPT_OLD_NORTH_ARABIAN,      "Narb" },
+    { G_UNICODE_SCRIPT_OLD_PERMIC,             "Perm" },
+    { G_UNICODE_SCRIPT_PAHAWH_HMONG,           "Hmng" },
+    { G_UNICODE_SCRIPT_PALMYRENE,              "Palm" },
+    { G_UNICODE_SCRIPT_PAU_CIN_HAU,            "Pauc" },
+    { G_UNICODE_SCRIPT_PSALTER_PAHLAVI,        "Phlp" },
+    { G_UNICODE_SCRIPT_SIDDHAM,                "Sidd" },
+    { G_UNICODE_SCRIPT_TIRHUTA,                "Tirh" },
+    { G_UNICODE_SCRIPT_WARANG_CITI,            "Wara" },
+
+    /* Unicode 8.0 additions */
+    { G_UNICODE_SCRIPT_AHOM,                   "Ahom" },
+    { G_UNICODE_SCRIPT_ANATOLIAN_HIEROGLYPHS,  "Hluw" },
+    { G_UNICODE_SCRIPT_HATRAN,                 "Hatr" },
+    { G_UNICODE_SCRIPT_MULTANI,                "Mult" },
+    { G_UNICODE_SCRIPT_OLD_HUNGARIAN,          "Hung" },
+    { G_UNICODE_SCRIPT_SIGNWRITING,            "Sgnw" },
+
+    /* Unicode 9.0 additions */
+    { G_UNICODE_SCRIPT_ADLAM,                  "Adlm" },
+    { G_UNICODE_SCRIPT_BHAIKSUKI,              "Bhks" },
+    { G_UNICODE_SCRIPT_MARCHEN,                "Marc" },
+    { G_UNICODE_SCRIPT_NEWA,                   "Newa" },
+    { G_UNICODE_SCRIPT_OSAGE,                  "Osge" },
+    { G_UNICODE_SCRIPT_TANGUT,                 "Tang" },
+
+    /* Unicode 10.0 additions */
+    { G_UNICODE_SCRIPT_MASARAM_GONDI,          "Gonm" },
+    { G_UNICODE_SCRIPT_NUSHU,                  "Nshu" },
+    { G_UNICODE_SCRIPT_SOYOMBO,                "Soyo" },
+    { G_UNICODE_SCRIPT_ZANABAZAR_SQUARE,       "Zanb" },
   };
   guint i;
 
